==> coil-0.13.0-javadoc.jar: coil-base/coil/-image-loader/-builder/index.md <==
[coil-base](../../../index.md) / [coil](../../index.md) / [ImageLoader](../index.md) / [Builder](./index.md)

# Builder

`class Builder`

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `Builder(context: `[`Context`](https://developer.android.com/reference/android/content/Context.html)`)` |

### Functions

| Name | Summary |
|---|---|
| [addLastModifiedToFileCacheKey](add-last-modified-to-file-cache-key.md) | Enables adding [File.lastModified](https://docs.oracle.com/javase/8/docs/api/java/io/File.html#lastModified()) to the memory cache key when loading an image from a [File](https://docs.oracle.com/javase/8/docs/api/java/io/File.html).`fun addLastModifiedToFileCacheKey(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [allowHardware](allow-hardware.md) | Allow the use of [Bitmap.Config.HARDWARE](https://developer.android.com/reference/android/graphics/Bitmap/Config.html#HARDWARE).`fun allowHardware(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [allowRgb565](allow-rgb565.md) | Allow automatically using [Bitmap.Config.RGB_565](https://developer.android.com/reference/android/graphics/Bitmap/Config.html#RGB_565) when an image is guaranteed to not have alpha.`fun allowRgb565(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [availableMemoryPercentage](available-memory-percentage.md) | Set the percentage of available memory to devote to this [ImageLoader](../index.md)'s memory cache and bitmap pool.`fun availableMemoryPercentage(percent: `[`Double`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-double/index.html)`): Builder` |
| [bitmapConfig](bitmap-config.md) | Set the preferred [Bitmap.Config](https://developer.android.com/reference/android/graphics/Bitmap/Config.html).`fun bitmapConfig(bitmapConfig: `[`Config`](https://developer.android.com/reference/android/graphics/Bitmap/Config.html)`): Builder` |
| [bitmapPoolingEnabled](bitmap-pooling-enabled.md) | Enables counting references to bitmaps so they can be automatically reused by a [BitmapPool](../../../coil.bitmap/-bitmap-pool/index.md) when their reference count reaches zero.`fun bitmapPoolingEnabled(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [bitmapPoolPercentage](bitmap-pool-percentage.md) | Set the percentage of memory allocated to this [ImageLoader](../index.md) to allocate to bitmap pooling.`fun bitmapPoolPercentage(percent: `[`Double`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-double/index.html)`): Builder` |
| [build](build.md) | Create a new [ImageLoader](../index.md) instance.`fun build(): `[`ImageLoader`](../index.md) |
| [callFactory](call-factory.md) | Set the [Call.Factory](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html) used for network requests.`fun callFactory(callFactory: `[`Factory`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html)`): Builder`<br>Set a lazy callback to create the [Call.Factory](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html) used for network requests.`fun callFactory(initializer: () -> `[`Factory`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html)`): Builder` |
| [componentRegistry](component-registry.md) | Build and set the [ComponentRegistry](../../-component-registry/index.md).`fun componentRegistry(builder: Builder.() -> `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)`): Builder`<br>Set the [ComponentRegistry](../../-component-registry/index.md).`fun componentRegistry(registry: `[`ComponentRegistry`](../../-component-registry/index.md)`): Builder` |
| [crossfade](crossfade.md) | Enable a crossfade animation with duration [CrossfadeDrawable.DEFAULT_DURATION](../../../coil.drawable/-crossfade-drawable/-d-e-f-a-u-l-t_-d-u-r-a-t-i-o-n.md) milliseconds when a request completes successfully.`fun crossfade(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder`<br>Enable a crossfade animation with [durationMillis](crossfade.md#coil.ImageLoader.Builder$crossfade(kotlin.Int)/durationMillis) milliseconds when a request completes successfully.`fun crossfade(durationMillis: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder` |
| [diskCachePolicy](disk-cache-policy.md) | Set the default disk cache policy.`fun diskCachePolicy(policy: `[`CachePolicy`](../../../coil.request/-cache-policy/index.md)`): Builder` |
| [dispatcher](dispatcher.md) | The default [CoroutineDispatcher](https://kotlin.github.io/kotlinx.coroutines/kotlinx-coroutines-core/kotlinx.coroutines/-coroutine-dispatcher/index.html) to run image requests on.`fun dispatcher(dispatcher: `[`CoroutineDispatcher`](https://kotlin.github.io/kotlinx.coroutines/kotlinx-coroutines-core/kotlinx.coroutines/-coroutine-dispatcher/index.html)`): Builder` |
| [error](error.md) | Set the default error drawable to use when a request fails.`fun error(drawableResId: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder`<br>`fun error(drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?): Builder` |
| [eventListener](event-listener.md) | Set a single [EventListener](../../-event-listener/index.md) that will receive all callbacks for requests launched by this image loader.`fun eventListener(listener: `[`EventListener`](../../-event-listener/index.md)`): Builder`<br>Set the [EventListener.Factory](../../-event-listener/-factory/index.md) to create per-request [EventListener](../../-event-listener/index.md)s.`fun eventListener(factory: Factory): Builder` |
| [fallback](fallback.md) | Set the default fallback drawable to use if [ImageRequest.data](../../../coil.request/-image-request/data.md) is null.`fun fallback(drawableResId: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder`<br>`fun fallback(drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?): Builder` |
| [launchInterceptorChainOnMainThread](launch-interceptor-chain-on-main-thread.md) | Enables launching the [Interceptor](../../../coil.intercept/-interceptor/index.md) chain on the main thread.`fun launchInterceptorChainOnMainThread(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [logger](logger.md) | Set the [Logger](../../../coil.util/-logger/index.md) to write logs to.`fun logger(logger: `[`Logger`](../../../coil.util/-logger/index.md)`?): Builder` |
| [memoryCachePolicy](memory-cache-policy.md) | Set the default memory cache policy.`fun memoryCachePolicy(policy: `[`CachePolicy`](../../../coil.request/-cache-policy/index.md)`): Builder` |
| [networkCachePolicy](network-cache-policy.md) | Set the default network cache policy.`fun networkCachePolicy(policy: `[`CachePolicy`](../../../coil.request/-cache-policy/index.md)`): Builder` |
| [okHttpClient](ok-http-client.md) | Set the [OkHttpClient](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html) used for network requests.`fun okHttpClient(okHttpClient: `[`OkHttpClient`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html)`): Builder`<br>Set a lazy callback to create the [OkHttpClient](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html) used for network requests.`fun okHttpClient(initializer: () -> `[`OkHttpClient`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html)`): Builder` |
| [placeholder](placeholder.md) | Set the default placeholder drawable to use when a request starts.`fun placeholder(drawableResId: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder`<br>`fun placeholder(drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?): Builder` |
| [precision](precision.md) | Set the default precision for a request. [Precision](../../../coil.size/-precision/index.md) controls whether the size of the loaded image must match the request's size exactly or not.`fun precision(precision: `[`Precision`](../../../coil.size/-precision/index.md)`): Builder` |
| [trackWeakReferences](track-weak-references.md) | Enables weak reference tracking of loaded images.`fun trackWeakReferences(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [transition](transition.md) | Set the default [Transition](../../../coil.transition/-transition/index.md) for each request.`fun transition(transition: `[`Transition`](../../../coil.transition/-transition/index.md)`): Builder` |

==> coil-1.1.1-javadoc.jar: coil-base/coil/-image-loader/-builder/index.md <==
[coil-base](../../../index.md) / [coil](../../index.md) / [ImageLoader](../index.md) / [Builder](./index.md)

# Builder

`class Builder`

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `Builder(context: `[`Context`](https://developer.android.com/reference/android/content/Context.html)`)` |

### Functions

| Name | Summary |
|---|---|
| [addLastModifiedToFileCacheKey](add-last-modified-to-file-cache-key.md) | Enables adding [File.lastModified](https://docs.oracle.com/javase/8/docs/api/java/io/File.html#lastModified()) to the memory cache key when loading an image from a [File](https://docs.oracle.com/javase/8/docs/api/java/io/File.html).`fun addLastModifiedToFileCacheKey(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [allowHardware](allow-hardware.md) | Allow the use of [Bitmap.Config.HARDWARE](https://developer.android.com/reference/android/graphics/Bitmap/Config.html#HARDWARE).`fun allowHardware(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [allowRgb565](allow-rgb565.md) | Allow automatically using [Bitmap.Config.RGB_565](https://developer.android.com/reference/android/graphics/Bitmap/Config.html#RGB_565) when an image is guaranteed to not have alpha.`fun allowRgb565(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [availableMemoryPercentage](available-memory-percentage.md) | Set the percentage of available memory to devote to this [ImageLoader](../index.md)'s memory cache and bitmap pool.`fun availableMemoryPercentage(percent: `[`Double`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-double/index.html)`): Builder` |
| [bitmapConfig](bitmap-config.md) | Set the preferred [Bitmap.Config](https://developer.android.com/reference/android/graphics/Bitmap/Config.html).`fun bitmapConfig(bitmapConfig: `[`Config`](https://developer.android.com/reference/android/graphics/Bitmap/Config.html)`): Builder` |
| [bitmapPoolingEnabled](bitmap-pooling-enabled.md) | Enables counting references to bitmaps so they can be automatically reused by a [BitmapPool](../../../coil.bitmap/-bitmap-pool/index.md) when their reference count reaches zero.`fun bitmapPoolingEnabled(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [bitmapPoolPercentage](bitmap-pool-percentage.md) | Set the percentage of memory allocated to this [ImageLoader](../index.md) to allocate to bitmap pooling.`fun bitmapPoolPercentage(percent: `[`Double`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-double/index.html)`): Builder` |
| [build](build.md) | Create a new [ImageLoader](../index.md) instance.`fun build(): `[`ImageLoader`](../index.md) |
| [callFactory](call-factory.md) | Set the [Call.Factory](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html) used for network requests.`fun callFactory(callFactory: `[`Factory`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html)`): Builder`<br>Set a lazy callback to create the [Call.Factory](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html) used for network requests.`fun callFactory(initializer: () -> `[`Factory`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/Call/Factory.html)`): Builder` |
| [componentRegistry](component-registry.md) | Build and set the [ComponentRegistry](../../-component-registry/index.md).`fun componentRegistry(builder: Builder.() -> `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)`): Builder`<br>Set the [ComponentRegistry](../../-component-registry/index.md).`fun componentRegistry(registry: `[`ComponentRegistry`](../../-component-registry/index.md)`): Builder` |
| [crossfade](crossfade.md) | Enable a crossfade animation with duration [CrossfadeDrawable.DEFAULT_DURATION](../../../coil.drawable/-crossfade-drawable/-d-e-f-a-u-l-t_-d-u-r-a-t-i-o-n.md) milliseconds when a request completes successfully.`fun crossfade(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder`<br>Enable a crossfade animation with [durationMillis](crossfade.md#coil.ImageLoader.Builder$crossfade(kotlin.Int)/durationMillis) milliseconds when a request completes successfully.`fun crossfade(durationMillis: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder` |
| [diskCachePolicy](disk-cache-policy.md) | Set the default disk cache policy.`fun diskCachePolicy(policy: `[`CachePolicy`](../../../coil.request/-cache-policy/index.md)`): Builder` |
| [dispatcher](dispatcher.md) | The default [CoroutineDispatcher](https://kotlin.github.io/kotlinx.coroutines/kotlinx-coroutines-core/kotlinx.coroutines/-coroutine-dispatcher/index.html) to run image requests on.`fun dispatcher(dispatcher: `[`CoroutineDispatcher`](https://kotlin.github.io/kotlinx.coroutines/kotlinx-coroutines-core/kotlinx.coroutines/-coroutine-dispatcher/index.html)`): Builder` |
| [error](error.md) | Set the default error drawable to use when a request fails.`fun error(drawableResId: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder`<br>`fun error(drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?): Builder` |
| [eventListener](event-listener.md) | Set a single [EventListener](../../-event-listener/index.md) that will receive all callbacks for requests launched by this image loader.`fun eventListener(listener: `[`EventListener`](../../-event-listener/index.md)`): <ERROR CLASS>`<br>Set the [EventListener.Factory](../../-event-listener/-factory/index.md) to create per-request [EventListener](../../-event-listener/index.md)s.`fun eventListener(factory: Factory): Builder` |
| [fallback](fallback.md) | Set the default fallback drawable to use if [ImageRequest.data](../../../coil.request/-image-request/data.md) is null.`fun fallback(drawableResId: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder`<br>`fun fallback(drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?): Builder` |
| [launchInterceptorChainOnMainThread](launch-interceptor-chain-on-main-thread.md) | Enables launching the [Interceptor](../../../coil.intercept/-interceptor/index.md) chain on the main thread.`fun launchInterceptorChainOnMainThread(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [logger](logger.md) | Set the [Logger](../../../coil.util/-logger/index.md) to write logs to.`fun logger(logger: `[`Logger`](../../../coil.util/-logger/index.md)`?): Builder` |
| [memoryCachePolicy](memory-cache-policy.md) | Set the default memory cache policy.`fun memoryCachePolicy(policy: `[`CachePolicy`](../../../coil.request/-cache-policy/index.md)`): Builder` |
| [networkCachePolicy](network-cache-policy.md) | Set the default network cache policy.`fun networkCachePolicy(policy: `[`CachePolicy`](../../../coil.request/-cache-policy/index.md)`): Builder` |
| [okHttpClient](ok-http-client.md) | Set the [OkHttpClient](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html) used for network requests.`fun okHttpClient(okHttpClient: `[`OkHttpClient`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html)`): Builder`<br>Set a lazy callback to create the [OkHttpClient](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html) used for network requests.`fun okHttpClient(initializer: () -> `[`OkHttpClient`](https://square.github.io/okhttp/3.x/okhttp/okhttp3/OkHttpClient.html)`): Builder` |
| [placeholder](placeholder.md) | Set the default placeholder drawable to use when a request starts.`fun placeholder(drawableResId: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`): Builder`<br>`fun placeholder(drawable: `[`Drawable`](https://developer.android.com/reference/android/graphics/drawable/Drawable.html)`?): Builder` |
| [precision](precision.md) | Set the default precision for a request. [Precision](../../../coil.size/-precision/index.md) controls whether the size of the loaded image must match the request's size exactly or not.`fun precision(precision: `[`Precision`](../../../coil.size/-precision/index.md)`): Builder` |
| [trackWeakReferences](track-weak-references.md) | Enables weak reference tracking of loaded images.`fun trackWeakReferences(enable: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): Builder` |
| [transition](transition.md) | Set the default [Transition](../../../coil.transition/-transition/index.md) for each request.`fun transition(transition: `[`Transition`](../../../coil.transition/-transition/index.md)`): Builder` |
